==> metron-tagger-1.0.6.tar.gz: metron-tagger-1.0.6/metrontagger/taggerlib/filesorter.py <==
"""Class to sort comic file based on it's metadata tags"""
import pathlib
from os import fspath
from shutil import Error, move

from darkseid.comicarchive import ComicArchive

from .utils import cleanup_string


class FileSorter:
    """Class to move comic files based on it's metadata tags"""

    def __init__(self, directory):
        self.sort_directory = directory

    def sort_comics(self, comic):
        """Method to move the comic file based on it's metadata tag"""
        comic_archive = ComicArchive(comic)
        if comic_archive.has_metadata():
            meta_data = comic_archive.read_metadata()
        else:
            return False

        publisher = cleanup_string(meta_data.publisher)
        series = cleanup_string(meta_data.series)
        volume = "v" + cleanup_string(meta_data.volume)
        new_path = pathlib.Path(self.sort_directory) / publisher / series / volume

        if not new_path.is_dir():
            try:
                new_path.mkdir(parents=True)
            except PermissionError:
                print(
                    f"due to permission error, failed to create directory: {new_path}"
                )
                return False

        original_path = pathlib.Path(comic)
        try:
            # Until python 3.9 is released, we need to force the Path
            # objects to strings so shutils.move will work correctly.
            move(fspath(original_path), fspath(new_path))
            print(f"moved '{original_path.name}' to '{new_path}'")
        except Error:
            return False

        return True

==> metron-tagger-1.0.10.tar.gz: metron-tagger-1.0.10/metrontagger/taggerlib/filesorter.py <==
"""Class to sort comic file based on it's metadata tags"""
import logging
import pathlib
from os import fspath
from pathlib import Path
from shutil import Error, move

from darkseid.comicarchive import ComicArchive

from .utils import cleanup_string

logger = logging.getLogger(__name__)


class FileSorter:
    """Class to move comic files based on it's metadata tags"""

    def __init__(self, directory: str) -> None:
        self.sort_directory = directory

    def sort_comics(self, comic: Path) -> bool:
        """Method to move the comic file based on it's metadata tag"""
        comic_archive = ComicArchive(comic)
        if comic_archive.has_metadata():
            meta_data = comic_archive.read_metadata()
        else:
            return False

        publisher = cleanup_string(meta_data.publisher)
        series = cleanup_string(meta_data.series)
        volume = cleanup_string(meta_data.volume)
        if volume is not None:
            volume = "v" + volume

        if (publisher and series and volume) is None:
            logger.warning(
                "Missing metadata from comic and will be unable to sort."
                + f"Publisher: {publisher}\nSeries: {series}\nVolume: {volume}"
            )
            return False

        new_path = pathlib.Path(self.sort_directory) / publisher / series / volume

        if not new_path.is_dir():
            try:
                new_path.mkdir(parents=True)
            except PermissionError:
                logger.exception(
                    f"due to permission error, failed to create directory: {new_path}"
                )
                return False

        original_path = pathlib.Path(comic)
        try:
            # Until python 3.9 is released, we need to force the Path
            # objects to strings so shutils.move will work correctly.
            move(fspath(original_path), fspath(new_path))
            print(f"moved '{original_path.name}' to '{new_path}'")
        except Error as e:
            logger.exception(f"Unable to move comic. Error: {e}")
            return False

        return True
